@@ -109,7 +109,7 @@ class SHCAPI:
             return None
         return result
 
-    def long_polling_poll(self, wait_seconds=0):
+    async def long_polling_poll(self, wait_seconds=0):
         api_url = f"{self._api_root}/read"
         data = {"requestAttr": "readall"}
 
@@ -127,13 +127,17 @@ class SHCAPI:
                 "id": [
                     {
                         "data": device.data,
-                        "sIT600TH": {"SetHeatingSetpoint_x100": int((round(celsius * 2) / 2) * 100)}
+                        "sIT600TH": {
+                            "SetHeatingSetpoint_x100": int((round(celsius * 2) / 2) * 100),
+                            "SetHoldType": 2
+                        }
                     }
                 ]
             }
 
         try:
-            result = await self._post_api_or_fail(api_url, data)
+            result = self._post_api_or_fail(api_url, data)
+            print(result)
         except Exception as e:
             logging.error(f"Failed to set temperature for device with id: {device.unique_id}")
             return None
@@ -141,17 +145,22 @@ class SHCAPI:
 
     async def set_climate_device_mode(self, device, mode: str):
         api_url = f"{self._api_root}/write"
+        print(device.previous_mode)
         data = {
                 "requestAttr": "write",
                 "id": [
                     {
                         "data": device.data,
-                        "sIT600TH": {"SetHoldType": 7 if mode == HVAC_MODE_OFF else device.previous_mode}
+                        "sIT600TH": {
+                            "SetHoldType":
+                                7 if mode == HVAC_MODE_OFF else device.previous_mode
+                                if not device.previous_mode == HVAC_MODE_OFF else 7
+                        }
                     }
                 ]
             }
         try:
-            result = await self._post_api_or_fail(api_url, data)
+            result = self._post_api_or_fail(api_url, data)
         except Exception as e:
             logging.error(f"Failed to set mode for device with id: {device.unique_id}")
             return None
@@ -171,9 +180,10 @@ class SHCAPI:
                 ]
             }
         try:
-            result = await self._post_api_or_fail(api_url, data)
+            result = self._post_api_or_fail(api_url, data)
         except Exception as e:
             logging.error(f"Failed to set preset for device with id: {device.unique_id}")
+            logging.error(e)
             return None
         return result
 
